@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 from builtins import range
 import os
 import numpy as np
@@ -12,9 +13,10 @@ from ..utils import NUMPY_MMAP
 
 
 class ICCInputSpec(BaseInterfaceInputSpec):
-    subjects_sessions = traits.List(traits.List(File(exists=True)),
-                                    desc="n subjects m sessions 3D stat files",
-                                    mandatory=True)
+    subjects_sessions = traits.List(
+        traits.List(File(exists=True)),
+        desc="n subjects m sessions 3D stat files",
+        mandatory=True)
     mask = File(exists=True, mandatory=True)
 
 
@@ -36,10 +38,16 @@ class ICC(BaseInterface):
 
     def _run_interface(self, runtime):
         maskdata = nb.load(self.inputs.mask).get_data()
-        maskdata = np.logical_not(np.logical_or(maskdata == 0, np.isnan(maskdata)))
+        maskdata = np.logical_not(
+            np.logical_or(maskdata == 0, np.isnan(maskdata)))
 
-        session_datas = [[nb.load(fname, mmap=NUMPY_MMAP).get_data()[maskdata].reshape(-1, 1) for fname in sessions] for sessions in self.inputs.subjects_sessions]
-        list_of_sessions = [np.dstack(session_data) for session_data in session_datas]
+        session_datas = [[
+            nb.load(fname, mmap=NUMPY_MMAP).get_data()[maskdata].reshape(
+                -1, 1) for fname in sessions
+        ] for sessions in self.inputs.subjects_sessions]
+        list_of_sessions = [
+            np.dstack(session_data) for session_data in session_datas
+        ]
         all_data = np.hstack(list_of_sessions)
         icc = np.zeros(session_datas[0][0].shape)
         session_F = np.zeros(session_datas[0][0].shape)
@@ -48,21 +56,22 @@ class ICC(BaseInterface):
 
         for x in range(icc.shape[0]):
             Y = all_data[x, :, :]
-            icc[x], subject_var[x], session_var[x], session_F[x], _, _ = ICC_rep_anova(Y)
+            icc[x], subject_var[x], session_var[x], session_F[
+                x], _, _ = ICC_rep_anova(Y)
 
         nim = nb.load(self.inputs.subjects_sessions[0][0])
         new_data = np.zeros(nim.shape)
-        new_data[maskdata] = icc.reshape(-1,)
+        new_data[maskdata] = icc.reshape(-1, )
         new_img = nb.Nifti1Image(new_data, nim.affine, nim.header)
         nb.save(new_img, 'icc_map.nii')
 
         new_data = np.zeros(nim.shape)
-        new_data[maskdata] = session_var.reshape(-1,)
+        new_data[maskdata] = session_var.reshape(-1, )
         new_img = nb.Nifti1Image(new_data, nim.affine, nim.header)
         nb.save(new_img, 'session_var_map.nii')
 
         new_data = np.zeros(nim.shape)
-        new_data[maskdata] = subject_var.reshape(-1,)
+        new_data[maskdata] = subject_var.reshape(-1, )
         new_img = nb.Nifti1Image(new_data, nim.affine, nim.header)
         nb.save(new_img, 'subject_var_map.nii')
 
@@ -71,7 +80,6 @@ class ICC(BaseInterface):
     def _list_outputs(self):
         outputs = self._outputs().get()
         outputs['icc_map'] = os.path.abspath('icc_map.nii')
-        outputs['sessions_F_map'] = os.path.abspath('sessions_F_map.nii')
         outputs['session_var_map'] = os.path.abspath('session_var_map.nii')
         outputs['subject_var_map'] = os.path.abspath('subject_var_map.nii')
         return outputs
@@ -97,7 +105,7 @@ def ICC_rep_anova(Y):
 
     # Sum Square Total
     mean_Y = mean(Y)
-    SST = ((Y - mean_Y) ** 2).sum()
+    SST = ((Y - mean_Y)**2).sum()
 
     # create the design matrix for the different levels
     x = kron(eye(nb_conditions), ones((nb_subjects, 1)))  # sessions
@@ -107,14 +115,14 @@ def ICC_rep_anova(Y):
     # Sum Square Error
     predicted_Y = dot(dot(dot(X, pinv(dot(X.T, X))), X.T), Y.flatten('F'))
     residuals = Y.flatten('F') - predicted_Y
-    SSE = (residuals ** 2).sum()
+    SSE = (residuals**2).sum()
 
     residuals.shape = Y.shape
 
     MSE = SSE / dfe
 
     # Sum square session effect - between colums/sessions
-    SSC = ((mean(Y, 0) - mean_Y) ** 2).sum() * nb_subjects
+    SSC = ((mean(Y, 0) - mean_Y)**2).sum() * nb_subjects
     MSC = SSC / dfc / nb_subjects
 
     session_effect_F = MSC / MSE
@@ -123,7 +131,8 @@ def ICC_rep_anova(Y):
     SSR = SST - SSC - SSE
     MSR = SSR / dfr
 
-    # ICC(3,1) = (mean square subjeT - mean square error) / (mean square subjeT + (k-1)*-mean square error)
+    # ICC(3,1) = (mean square subjeT - mean square error) /
+    #            (mean square subjeT + (k-1)*-mean square error)
     ICC = (MSR - MSE) / (MSR + dfc * MSE)
 
     e_var = MSE  # variance of error
