@@ -359,7 +359,8 @@ class ApplyTransformsInputSpec(ANTSCommandInputSpec):
         desc='output a composite warp file instead of a transformed image')
     float = traits.Bool(
         argstr='--float %d',
-        default=False,
+        default_value=False,
+        usedefault=True,
         desc='Use float instead of double for computations.')
 
 
@@ -380,7 +381,7 @@ class ApplyTransforms(ANTSCommand):
     >>> at.inputs.reference_image = 'fixed1.nii'
     >>> at.inputs.transforms = 'identity'
     >>> at.cmdline
-    'antsApplyTransforms --default-value 0 --input moving1.nii \
+    'antsApplyTransforms --default-value 0 --float 0 --input moving1.nii \
 --interpolation Linear --output moving1_trans.nii \
 --reference-image fixed1.nii -t identity'
 
@@ -394,9 +395,9 @@ class ApplyTransforms(ANTSCommand):
     >>> at.inputs.transforms = ['ants_Warp.nii.gz', 'trans.mat']
     >>> at.inputs.invert_transform_flags = [False, False]
     >>> at.cmdline
-    'antsApplyTransforms --default-value 0 --dimensionality 3 --input moving1.nii --interpolation Linear \
---output deformed_moving1.nii --reference-image fixed1.nii --transform [ ants_Warp.nii.gz, 0 ] \
---transform [ trans.mat, 0 ]'
+    'antsApplyTransforms --default-value 0 --dimensionality 3 --float 0 --input moving1.nii \
+--interpolation Linear --output deformed_moving1.nii --reference-image fixed1.nii \
+--transform [ ants_Warp.nii.gz, 0 ] --transform [ trans.mat, 0 ]'
 
     >>> at1 = ApplyTransforms()
     >>> at1.inputs.dimension = 3
@@ -409,9 +410,9 @@ class ApplyTransforms(ANTSCommand):
     >>> at1.inputs.transforms = ['ants_Warp.nii.gz', 'trans.mat']
     >>> at1.inputs.invert_transform_flags = [False, False]
     >>> at1.cmdline
-    'antsApplyTransforms --default-value 0 --dimensionality 3 --input moving1.nii --interpolation BSpline[ 5 ] \
---output deformed_moving1.nii --reference-image fixed1.nii --transform [ ants_Warp.nii.gz, 0 ] \
---transform [ trans.mat, 0 ]'
+    'antsApplyTransforms --default-value 0 --dimensionality 3 --float 0 --input moving1.nii \
+--interpolation BSpline[ 5 ] --output deformed_moving1.nii --reference-image fixed1.nii \
+--transform [ ants_Warp.nii.gz, 0 ] --transform [ trans.mat, 0 ]'
     """
     _cmd = 'antsApplyTransforms'
     input_spec = ApplyTransformsInputSpec
@@ -492,15 +493,15 @@ class ApplyTransformsToPointsInputSpec(ANTSCommandInputSpec):
         argstr='--input %s',
         mandatory=True,
         desc=
-        ("Currently, the only input supported is a csv file with "
-         "columns including x,y (2D), x,y,z (3D) or x,y,z,t,label (4D) column headers."
-         "The points should be defined in physical space."
-         "If in doubt how to convert coordinates from your files to the space"
-         "required by antsApplyTransformsToPoints try creating/drawing a simple"
-         "label volume with only one voxel set to 1 and all others set to 0."
-         "Write down the voxel coordinates. Then use ImageMaths LabelStats to find"
-         "out what coordinates for this voxel antsApplyTransformsToPoints is"
-         "expecting."),
+        ("Currently, the only input supported is a csv file with"
+         " columns including x,y (2D), x,y,z (3D) or x,y,z,t,label (4D) column headers."
+         " The points should be defined in physical space."
+         " If in doubt how to convert coordinates from your files to the space"
+         " required by antsApplyTransformsToPoints try creating/drawing a simple"
+         " label volume with only one voxel set to 1 and all others set to 0."
+         " Write down the voxel coordinates. Then use ImageMaths LabelStats to find"
+         " out what coordinates for this voxel antsApplyTransformsToPoints is"
+         " expecting."),
         exists=True)
     output_file = traits.Str(
         argstr='--output %s',
