@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
 """ Base interfaces for dipy """
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 import os.path as op
 import numpy as np
 from ... import logging
-from ..base import (traits, File, isdefined,
-                    BaseInterface, BaseInterfaceInputSpec)
-
-IFLOGGER = logging.getLogger('interface')
+from ..base import (traits, File, isdefined, LibraryBaseInterface,
+                    BaseInterfaceInputSpec)
 
 HAVE_DIPY = True
 try:
@@ -31,16 +30,11 @@ def dipy_version():
     return dipy.__version__
 
 
-class DipyBaseInterface(BaseInterface):
-
+class DipyBaseInterface(LibraryBaseInterface):
     """
     A base interface for py:mod:`dipy` computations
     """
-    def __init__(self, **inputs):
-        if no_dipy():
-            IFLOGGER.warn('dipy was not found')
-            # raise ImportError('dipy was not found')
-        super(DipyBaseInterface, self).__init__(**inputs)
+    _pkg = 'dipy'
 
 
 class DipyBaseInterfaceInputSpec(BaseInterfaceInputSpec):
@@ -52,7 +46,6 @@ class DipyBaseInterfaceInputSpec(BaseInterfaceInputSpec):
 
 
 class DipyDiffusionInterface(DipyBaseInterface):
-
     """
     A base interface for py:mod:`dipy` computations
     """
