@@ -144,7 +144,7 @@ class FSLXCommandInputSpec(FSLCommandInputSpec):
     n_fibres = traits.Range(
         usedefault=True,
         low=1,
-        default=2,
+        value=2,
         argstr='--nfibres=%d',
         desc=('Maximum number of fibres to fit in each voxel'),
         mandatory=True)
@@ -158,27 +158,32 @@ class FSLXCommandInputSpec(FSLCommandInputSpec):
               'shell) model'))
     fudge = traits.Int(argstr='--fudge=%d', desc='ARD fudge factor')
     n_jumps = traits.Int(
-        5000, argstr='--njumps=%d', desc='Num of jumps to be made by MCMC')
+        5000, usedefault=True,
+        argstr='--njumps=%d', desc='Num of jumps to be made by MCMC')
     burn_in = traits.Range(
         low=0,
-        default=0,
+        value=0,
+        usedefault=True,
         argstr='--burnin=%d',
         desc=('Total num of jumps at start of MCMC to be '
               'discarded'))
     burn_in_no_ard = traits.Range(
         low=0,
-        default=0,
-        argstr='--burninnoard=%d',
+        value=0,
+        usedefault=True,
+        argstr='--burnin_noard=%d',
         desc=('num of burnin jumps before the ard is'
               ' imposed'))
     sample_every = traits.Range(
         low=0,
-        default=1,
+        value=1,
+        usedefault=True,
         argstr='--sampleevery=%d',
         desc='Num of jumps for each sample (MCMC)')
     update_proposal_every = traits.Range(
         low=1,
-        default=40,
+        value=40,
+        usedefault=True,
         argstr='--updateproposalevery=%d',
         desc=('Num of jumps for each update '
               'to the proposal density std '
@@ -322,7 +327,7 @@ class BEDPOSTX5InputSpec(FSLXCommandInputSpec):
     n_fibres = traits.Range(
         usedefault=True,
         low=1,
-        default=2,
+        value=2,
         argstr='-n %d',
         desc=('Maximum number of fibres to fit in each voxel'),
         mandatory=True)
@@ -336,16 +341,19 @@ class BEDPOSTX5InputSpec(FSLXCommandInputSpec):
               'shell) model'))
     fudge = traits.Int(argstr='-w %d', desc='ARD fudge factor')
     n_jumps = traits.Int(
-        5000, argstr='-j %d', desc='Num of jumps to be made by MCMC')
+        5000, usedefault=True,
+        argstr='-j %d', desc='Num of jumps to be made by MCMC')
     burn_in = traits.Range(
         low=0,
-        default=0,
+        value=0,
+        usedefault=True,
         argstr='-b %d',
         desc=('Total num of jumps at start of MCMC to be '
               'discarded'))
     sample_every = traits.Range(
         low=0,
-        default=1,
+        value=1,
+        usedefault=True,
         argstr='-s %d',
         desc='Num of jumps for each sample (MCMC)')
     out_dir = Directory(
@@ -416,7 +424,8 @@ class BEDPOSTX5(FSLXCommand):
     >>> bedp = fsl.BEDPOSTX5(bvecs='bvecs', bvals='bvals', dwi='diffusion.nii',
     ...                     mask='mask.nii', n_fibres=1)
     >>> bedp.cmdline
-    'bedpostx bedpostx --forcedir -n 1'
+    'bedpostx bedpostx -b 0 --burnin_noard=0 --forcedir -n 1 -j 5000 \
+-s 1 --updateproposalevery=40'
 
     """
 
@@ -842,7 +851,6 @@ class ProbTrackX2InputSpec(ProbTrackXBaseInputSpec):
     simple = traits.Bool(
         desc=('rack from a list of voxels (seed must be a '
               'ASCII list of coordinates)'),
-        usedefault=False,
         argstr='--simple')
     fopd = File(
         exists=True,
