@@ -24,10 +24,10 @@ from future import standard_library
 
 from ... import config, logging
 from ...utils.misc import flatten, unflatten, str2bool, dict_diff
-from ...utils.filemanip import (md5, FileNotFoundError, filename_to_list,
-                                list_to_filename, copyfiles, fnames_presuffix,
+from ...utils.filemanip import (md5, FileNotFoundError, ensure_list,
+                                simplify_list, copyfiles, fnames_presuffix,
                                 loadpkl, split_filename, load_json, makedirs,
-                                emptydirs, savepkl, to_str)
+                                emptydirs, savepkl, to_str, indirectory)
 
 from ...interfaces.base import (traits, InputMultiPath, CommandLine, Undefined,
                                 DynamicTraitedSpec, Bunch, InterfaceResult,
@@ -41,7 +41,7 @@ from .base import EngineBase
 
 standard_library.install_aliases()
 
-logger = logging.getLogger('workflow')
+logger = logging.getLogger('nipype.workflow')
 
 
 class Node(EngineBase):
@@ -183,6 +183,7 @@ class Node(EngineBase):
         self._hashed_inputs = None
         self._needed_outputs = []
         self.needed_outputs = needed_outputs
+        self.config = None
 
     @property
     def interface(self):
@@ -274,7 +275,7 @@ class Node(EngineBase):
                 params_str = [_parameterization_dir(p) for p in params_str]
             outputdir = op.join(outputdir, *params_str)
 
-        self._output_dir = op.abspath(op.join(outputdir, self.name))
+        self._output_dir = op.realpath(op.join(outputdir, self.name))
         return self._output_dir
 
     def set_input(self, parameter, val):
@@ -531,8 +532,8 @@ class Node(EngineBase):
             else:
                 output_name = info[1]
                 try:
-                    output_value = results.outputs.get()[output_name]
-                except TypeError:
+                    output_value = results.outputs.trait_get()[output_name]
+                except AttributeError:
                     output_value = results.outputs.dictcopy()[output_name]
             logger.debug('output: %s', output_name)
             try:
@@ -627,7 +628,8 @@ class Node(EngineBase):
             self._interface.__class__.__name__)
         if issubclass(self._interface.__class__, CommandLine):
             try:
-                cmd = self._interface.cmdline
+                with indirectory(outdir):
+                    cmd = self._interface.cmdline
             except Exception as msg:
                 result.runtime.stderr = '{}\n\n{}'.format(
                     getattr(result.runtime, 'stderr', ''), msg)
@@ -677,11 +679,11 @@ class Node(EngineBase):
             makedirs(outdir, exist_ok=True)
 
         for info in self._interface._get_filecopy_info():
-            files = self.inputs.get().get(info['key'])
+            files = self.inputs.trait_get().get(info['key'])
             if not isdefined(files) or not files:
                 continue
 
-            infiles = filename_to_list(files)
+            infiles = ensure_list(files)
             if execute:
                 if linksonly:
                     if not info['copy']:
@@ -700,7 +702,7 @@ class Node(EngineBase):
             else:
                 newfiles = fnames_presuffix(infiles, newpath=outdir)
             if not isinstance(files, list):
-                newfiles = list_to_filename(newfiles)
+                newfiles = simplify_list(newfiles)
             setattr(self.inputs, info['key'], newfiles)
         if execute and linksonly:
             emptydirs(outdir, noexist_ok=True)
@@ -1083,7 +1085,7 @@ class MapNode(Node):
     @property
     def outputs(self):
         if self._interface._outputs():
-            return Bunch(self._interface._outputs().get())
+            return Bunch(self._interface._outputs().trait_get())
 
     def _make_nodes(self, cwd=None):
         if cwd is None:
@@ -1091,10 +1093,10 @@ class MapNode(Node):
         if self.nested:
             nitems = len(
                 flatten(
-                    filename_to_list(getattr(self.inputs, self.iterfield[0]))))
+                    ensure_list(getattr(self.inputs, self.iterfield[0]))))
         else:
             nitems = len(
-                filename_to_list(getattr(self.inputs, self.iterfield[0])))
+                ensure_list(getattr(self.inputs, self.iterfield[0])))
         for i in range(nitems):
             nodename = '_%s%d' % (self.name, i)
             node = Node(
@@ -1108,14 +1110,14 @@ class MapNode(Node):
                 name=nodename)
             node.plugin_args = self.plugin_args
             node.interface.inputs.trait_set(
-                **deepcopy(self._interface.inputs.get()))
+                **deepcopy(self._interface.inputs.trait_get()))
             node.interface.resource_monitor = self._interface.resource_monitor
             for field in self.iterfield:
                 if self.nested:
                     fieldvals = flatten(
-                        filename_to_list(getattr(self.inputs, field)))
+                        ensure_list(getattr(self.inputs, field)))
                 else:
-                    fieldvals = filename_to_list(getattr(self.inputs, field))
+                    fieldvals = ensure_list(getattr(self.inputs, field))
                 logger.debug('setting input %d %s %s', i, field, fieldvals[i])
                 setattr(node.inputs, field, fieldvals[i])
             node.config = self.config
@@ -1152,7 +1154,7 @@ class MapNode(Node):
                     if not isdefined(values):
                         values = []
                     if nresult and nresult.outputs:
-                        values.insert(i, nresult.outputs.get()[key])
+                        values.insert(i, nresult.outputs.trait_get()[key])
                     else:
                         values.insert(i, None)
                     defined_vals = [isdefined(val) for val in values]
@@ -1164,7 +1166,7 @@ class MapNode(Node):
                 values = getattr(finalresult.outputs, key)
                 if isdefined(values):
                     values = unflatten(values,
-                                       filename_to_list(
+                                       ensure_list(
                                            getattr(self.inputs,
                                                    self.iterfield[0])))
                 setattr(finalresult.outputs, key, values)
@@ -1195,12 +1197,12 @@ class MapNode(Node):
             return 1
         if self.nested:
             return len(
-                filename_to_list(
+                ensure_list(
                     flatten(getattr(self.inputs, self.iterfield[0]))))
-        return len(filename_to_list(getattr(self.inputs, self.iterfield[0])))
+        return len(ensure_list(getattr(self.inputs, self.iterfield[0])))
 
     def _get_inputs(self):
-        old_inputs = self._inputs.get()
+        old_inputs = self._inputs.trait_get()
         self._inputs = self._create_dynamic_traits(
             self._interface.inputs, fields=self.iterfield)
         self._inputs.trait_set(**old_inputs)
@@ -1218,10 +1220,10 @@ class MapNode(Node):
                                   "in iterfields.") % iterfield)
         if len(self.iterfield) > 1:
             first_len = len(
-                filename_to_list(getattr(self.inputs, self.iterfield[0])))
+                ensure_list(getattr(self.inputs, self.iterfield[0])))
             for iterfield in self.iterfield[1:]:
                 if first_len != len(
-                        filename_to_list(getattr(self.inputs, iterfield))):
+                        ensure_list(getattr(self.inputs, iterfield))):
                     raise ValueError(
                         ("All iterfields of a MapNode have to "
                          "have the same length. %s") % str(self.inputs))
@@ -1240,11 +1242,11 @@ class MapNode(Node):
         # Set up mapnode folder names
         if self.nested:
             nitems = len(
-                filename_to_list(
+                ensure_list(
                     flatten(getattr(self.inputs, self.iterfield[0]))))
         else:
             nitems = len(
-                filename_to_list(getattr(self.inputs, self.iterfield[0])))
+                ensure_list(getattr(self.inputs, self.iterfield[0])))
         nnametpl = '_%s{}' % self.name
         nodenames = [nnametpl.format(i) for i in range(nitems)]
 
